@@ -9,17 +9,16 @@ attempt fails with a SystemExit exception that has an SKBuildError exception as
 its value.
 """
 
-import pytest
+from subprocess import CalledProcessError, check_output
 
-from subprocess import (check_output, CalledProcessError)
+import pytest
 
 from skbuild.constants import CMAKE_DEFAULT_EXECUTABLE
 from skbuild.exceptions import SKBuildError
 from skbuild.platform_specifics import CMakeGenerator, get_platform
 from skbuild.utils import push_dir
 
-from . import project_setup_py_test
-from . import push_env
+from . import project_setup_py_test, push_env
 
 
 def test_cmakelists_with_fatalerror_fails(capfd):
@@ -64,7 +63,7 @@ def test_cmakelists_with_syntaxerror_fails(capfd):
     assert failed
 
     _, err = capfd.readouterr()
-    assert "Parse error.  Function missing ending \")\"" in err
+    assert 'Parse error.  Function missing ending ")"' in err
     assert "An error occurred while configuring with CMake." in message
 
 
@@ -95,19 +94,18 @@ def test_hello_with_compileerror_fails(capfd):
 def test_invalid_cmake(exception, mocker):
 
     exceptions = {
-        OSError: OSError('Unknown error'),
-        CalledProcessError: CalledProcessError([CMAKE_DEFAULT_EXECUTABLE, '--version'], 1)
+        OSError: OSError("Unknown error"),
+        CalledProcessError: CalledProcessError([CMAKE_DEFAULT_EXECUTABLE, "--version"], 1),
     }
 
     check_output_original = check_output
 
     def check_output_mock(*args, **kwargs):
-        if args[0] == [CMAKE_DEFAULT_EXECUTABLE, '--version']:
+        if args[0] == [CMAKE_DEFAULT_EXECUTABLE, "--version"]:
             raise exceptions[exception]
         return check_output_original(*args, **kwargs)
 
-    mocker.patch('skbuild.cmaker.subprocess.check_output',
-                 new=check_output_mock)
+    mocker.patch("skbuild.cmaker.subprocess.check_output", new=check_output_mock)
 
     with push_dir():
 
@@ -129,15 +127,16 @@ def test_invalid_cmake(exception, mocker):
 
 def test_first_invalid_generator(mocker, capfd):
     platform = get_platform()
-    default_generators = [CMakeGenerator('Invalid')]
+    default_generators = [CMakeGenerator("Invalid")]
     default_generators.extend(platform.default_generators)
-    mocker.patch.object(type(platform), 'default_generators',
-                        new_callable=mocker.PropertyMock,
-                        return_value=default_generators)
+    mocker.patch.object(
+        type(platform), "default_generators", new_callable=mocker.PropertyMock, return_value=default_generators
+    )
 
-    mocker.patch('skbuild.cmaker.get_platform', return_value=platform)
+    mocker.patch("skbuild.cmaker.get_platform", return_value=platform)
 
     with push_dir(), push_env(CMAKE_GENERATOR=None):
+
         @project_setup_py_test("hello-no-language", ["build"])
         def run_build():
             pass
@@ -150,12 +149,13 @@ def test_first_invalid_generator(mocker, capfd):
 
 def test_invalid_generator(mocker, capfd):
     platform = get_platform()
-    mocker.patch.object(type(platform), 'default_generators',
-                        new_callable=mocker.PropertyMock,
-                        return_value=[CMakeGenerator('Invalid')])
-    mocker.patch('skbuild.cmaker.get_platform', return_value=platform)
+    mocker.patch.object(
+        type(platform), "default_generators", new_callable=mocker.PropertyMock, return_value=[CMakeGenerator("Invalid")]
+    )
+    mocker.patch("skbuild.cmaker.get_platform", return_value=platform)
 
     with push_dir(), push_env(CMAKE_GENERATOR=None):
+
         @project_setup_py_test("hello-no-language", ["build"])
         def should_fail():
             pass
@@ -172,5 +172,4 @@ def test_invalid_generator(mocker, capfd):
 
     assert "CMake Error: Could not create named generator Invalid" in err
     assert failed
-    assert "scikit-build could not get a working generator for your system." \
-           " Aborting build." in message
+    assert "scikit-build could not get a working generator for your system." " Aborting build." in message
