@@ -10,12 +10,13 @@ keyword works.
 """
 
 import glob
-import pytest
 import textwrap
 
+import pytest
+
 from skbuild.exceptions import SKBuildError
 
-from . import (_tmpdir, execute_setup_py, project_setup_py_test)
+from . import _tmpdir, execute_setup_py, project_setup_py_test
 from .pytest_helpers import check_sdist_content
 
 
@@ -23,19 +24,23 @@ from .pytest_helpers import check_sdist_content
 def test_build(capsys):
     out, err = capsys.readouterr()
     dist_warning = "Unknown distribution option: 'cmake_source_dir'"
-    assert (dist_warning not in err and dist_warning not in out)
+    assert dist_warning not in err and dist_warning not in out
 
 
-@pytest.mark.parametrize("cmake_source_dir, expected_failed", (
+@pytest.mark.parametrize(
+    "cmake_source_dir, expected_failed",
+    (
         ("invalid", True),
         ("", False),
         (".", False),
-))
+    ),
+)
 def test_cmake_source_dir(cmake_source_dir, expected_failed):
-    tmp_dir = _tmpdir('test_cmake_source_dir')
+    tmp_dir = _tmpdir("test_cmake_source_dir")
 
-    tmp_dir.join('setup.py').write(textwrap.dedent(
-        """
+    tmp_dir.join("setup.py").write(
+        textwrap.dedent(
+            """
         from skbuild import setup
         setup(
             name="test_cmake_source_dir",
@@ -45,13 +50,16 @@ def test_cmake_source_dir(cmake_source_dir, expected_failed):
             license="MIT",
             cmake_source_dir="{cmake_source_dir}"
         )
-        """.format(cmake_source_dir=cmake_source_dir)
-    ))
+        """.format(
+                cmake_source_dir=cmake_source_dir
+            )
+        )
+    )
 
     failed = False
     message = ""
     try:
-        with execute_setup_py(tmp_dir, ['build'], disable_languages_test=True):
+        with execute_setup_py(tmp_dir, ["build"], disable_languages_test=True):
             pass
     except SystemExit as e:
         failed = isinstance(e.code, SKBuildError)
@@ -64,22 +72,22 @@ def test_cmake_source_dir(cmake_source_dir, expected_failed):
 
 @project_setup_py_test("cmakelists-not-in-top-level-dir", ["sdist"], disable_languages_test=True)
 def test_hello_sdist():
-    sdists_tar = glob.glob('dist/*.tar.gz')
-    sdists_zip = glob.glob('dist/*.zip')
+    sdists_tar = glob.glob("dist/*.tar.gz")
+    sdists_zip = glob.glob("dist/*.zip")
     assert sdists_tar or sdists_zip
 
     expected_content = [
-        'hello-1.2.3/hello/_hello.cxx',
-        'hello-1.2.3/hello/CMakeLists.txt',
-        'hello-1.2.3/hello/__init__.py',
-        'hello-1.2.3/hello/__main__.py',
-        'hello-1.2.3/setup.py',
+        "hello-1.2.3/hello/_hello.cxx",
+        "hello-1.2.3/hello/CMakeLists.txt",
+        "hello-1.2.3/hello/__init__.py",
+        "hello-1.2.3/hello/__main__.py",
+        "hello-1.2.3/setup.py",
     ]
 
     sdist_archive = None
     if sdists_tar:
-        sdist_archive = 'dist/hello-1.2.3.tar.gz'
+        sdist_archive = "dist/hello-1.2.3.tar.gz"
     elif sdists_zip:
-        sdist_archive = 'dist/hello-1.2.3.zip'
+        sdist_archive = "dist/hello-1.2.3.zip"
 
-    check_sdist_content(sdist_archive, 'hello-1.2.3', expected_content)
+    check_sdist_content(sdist_archive, "hello-1.2.3", expected_content)
