@@ -9,13 +9,13 @@ Tries to build and test the `hello-cpp` sample project.
 
 import glob
 import os
+
 import pytest
 
 from skbuild.constants import CMAKE_BUILD_DIR, CMAKE_INSTALL_DIR, SKBUILD_DIR
 from skbuild.utils import push_dir
 
-from . import get_ext_suffix, project_setup_py_test
-from . import (_copy_dir, _tmpdir, SAMPLES_DIR)
+from . import SAMPLES_DIR, _copy_dir, _tmpdir, get_ext_suffix, project_setup_py_test
 from .pytest_helpers import check_sdist_content, check_wheel_content
 
 
@@ -44,50 +44,50 @@ def test_hello_builds():
 
 @project_setup_py_test("hello-cpp", ["sdist"])
 def test_hello_sdist():
-    sdists_tar = glob.glob('dist/*.tar.gz')
-    sdists_zip = glob.glob('dist/*.zip')
+    sdists_tar = glob.glob("dist/*.tar.gz")
+    sdists_zip = glob.glob("dist/*.zip")
     assert sdists_tar or sdists_zip
 
     expected_content = [
-        'hello-1.2.3/CMakeLists.txt',
-        'hello-1.2.3/bonjour/__init__.py',
-        'hello-1.2.3/bonjour/data/ciel.txt',
-        'hello-1.2.3/bonjour/data/soleil.txt',
-        'hello-1.2.3/bonjour/data/terre.txt',
-        'hello-1.2.3/bonjourModule.py',
-        'hello-1.2.3/hello/_hello.cxx',
-        'hello-1.2.3/hello/CMakeLists.txt',
-        'hello-1.2.3/hello/__init__.py',
-        'hello-1.2.3/hello/__main__.py',
-        'hello-1.2.3/setup.py',
+        "hello-1.2.3/CMakeLists.txt",
+        "hello-1.2.3/bonjour/__init__.py",
+        "hello-1.2.3/bonjour/data/ciel.txt",
+        "hello-1.2.3/bonjour/data/soleil.txt",
+        "hello-1.2.3/bonjour/data/terre.txt",
+        "hello-1.2.3/bonjourModule.py",
+        "hello-1.2.3/hello/_hello.cxx",
+        "hello-1.2.3/hello/CMakeLists.txt",
+        "hello-1.2.3/hello/__init__.py",
+        "hello-1.2.3/hello/__main__.py",
+        "hello-1.2.3/setup.py",
     ]
 
-    sdist_archive = 'dist/hello-1.2.3.zip'
+    sdist_archive = "dist/hello-1.2.3.zip"
     if sdists_tar:
-        sdist_archive = 'dist/hello-1.2.3.tar.gz'
+        sdist_archive = "dist/hello-1.2.3.tar.gz"
 
-    check_sdist_content(sdist_archive, 'hello-1.2.3', expected_content)
+    check_sdist_content(sdist_archive, "hello-1.2.3", expected_content)
 
 
 def test_hello_wheel():
     expected_content = [
-        'hello/_hello%s' % get_ext_suffix(),
-        'hello/__init__.py',
-        'hello/__main__.py',
-        'hello/world.py',
-        'helloModule.py',
-        'bonjour/__init__.py',
-        'bonjour/data/ciel.txt',
-        'bonjour/data/soleil.txt',
-        'bonjour/data/terre.txt',
-        'bonjourModule.py'
+        "hello/_hello%s" % get_ext_suffix(),
+        "hello/__init__.py",
+        "hello/__main__.py",
+        "hello/world.py",
+        "helloModule.py",
+        "bonjour/__init__.py",
+        "bonjour/data/ciel.txt",
+        "bonjour/data/soleil.txt",
+        "bonjour/data/terre.txt",
+        "bonjourModule.py",
     ]
 
-    expected_distribution_name = 'hello-1.2.3'
+    expected_distribution_name = "hello-1.2.3"
 
     @project_setup_py_test("hello-cpp", ["bdist_wheel"])
     def build_wheel():
-        whls = glob.glob('dist/*.whl')
+        whls = glob.glob("dist/*.whl")
         assert len(whls) == 1
         check_wheel_content(whls[0], expected_distribution_name, expected_content)
         os.remove(whls[0])
@@ -101,18 +101,18 @@ def test_hello_wheel():
     @project_setup_py_test("hello-cpp", ["--skip-cmake", "bdist_wheel"], tmp_dir=tmp_dir)
     def build_wheel_skip_cmake():
         assert not os.path.exists(os.path.join(CMAKE_BUILD_DIR(), "CMakeCache.txt"))
-        whls = glob.glob('dist/*.whl')
+        whls = glob.glob("dist/*.whl")
         assert len(whls) == 1
         check_wheel_content(whls[0], expected_distribution_name, expected_content)
 
     build_wheel_skip_cmake()
 
 
-@pytest.mark.parametrize("dry_run", ['with-dry-run', 'without-dry-run'])
+@pytest.mark.parametrize("dry_run", ["with-dry-run", "without-dry-run"])
 def test_hello_clean(dry_run, capfd):
     with push_dir():
 
-        dry_run = dry_run == 'with-dry-run'
+        dry_run = dry_run == "with-dry-run"
 
         @project_setup_py_test("hello-cpp", ["build"])
         def run_build():
@@ -142,9 +142,9 @@ def test_hello_clean(dry_run, capfd):
         else:
             assert tmp_dir.join(SKBUILD_DIR()).exists()
 
-        build_out, clean_out = capfd.readouterr()[0].split('<<-->>')
-        assert 'Build files have been written to' in build_out
-        assert 'Build files have been written to' not in clean_out
+        build_out, clean_out = capfd.readouterr()[0].split("<<-->>")
+        assert "Build files have been written to" in build_out
+        assert "Build files have been written to" not in clean_out
 
 
 def test_hello_cleans(capfd, caplog):
@@ -169,8 +169,7 @@ def test_hello_cleans(capfd, caplog):
         print("<<-->>")
         run_clean()
 
-    _, clean1_out, clean2_out = \
-        capfd.readouterr()[0].split('<<-->>')
+    _, clean1_out, clean2_out = capfd.readouterr()[0].split("<<-->>")
 
     clean1_out = clean1_out.strip()
     clean2_out = clean2_out.strip()
@@ -188,18 +187,18 @@ def test_hello_cleans(capfd, caplog):
 def test_hello_develop():
     for expected_file in [
         # These files are the "regular" source files
-        'setup.py',
-        'CMakeLists.txt',
-        'bonjour/__init__.py',
-        'bonjourModule.py',
-        'hello/__init__.py',
-        'hello/__main__.py',
-        'hello/_hello.cxx',
-        'hello/CMakeLists.txt',
+        "setup.py",
+        "CMakeLists.txt",
+        "bonjour/__init__.py",
+        "bonjourModule.py",
+        "hello/__init__.py",
+        "hello/__main__.py",
+        "hello/_hello.cxx",
+        "hello/CMakeLists.txt",
         # These files are "generated" by CMake and
         # are copied from CMAKE_INSTALL_DIR
-        'hello/_hello%s' % get_ext_suffix(),
-        'hello/world.py',
-        'helloModule.py'
+        "hello/_hello%s" % get_ext_suffix(),
+        "hello/world.py",
+        "helloModule.py",
     ]:
         assert os.path.exists(expected_file)
