@@ -17,11 +17,7 @@ from skbuild.utils import push_dir
 from . import project_setup_py_test
 
 
-@pytest.mark.parametrize("option", [
-    None,
-    '-DINSTALL_FILE:BOOL=1',
-    '-DINSTALL_PROJECT:BOOL=1'
-])
+@pytest.mark.parametrize("option", [None, "-DINSTALL_FILE:BOOL=1", "-DINSTALL_PROJECT:BOOL=1"])
 def test_outside_project_root_fails(option):
 
     with push_dir():
